@@ -1328,6 +1328,10 @@ Un nouveau nom vous permettra de conserver l&apos;ancien document.</translation>
         <source>Are you sure you want to remove the selected item(s) ?</source>
         <translation>Voulez-vous vraiment supprimer le(s) élément(s) sélectionné(s) ?</translation>
     </message>
+    <message>
+        <source>Copying page %1/%2</source>
+        <translation>Copie de la page %1/%2 en cours</translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentTreeWidget</name>
@@ -2903,6 +2907,22 @@ p, li { white-space: pre-wrap; }
         <source>Swap first and second view displays</source>
         <translation>Inverser les écrans élèves</translation>
     </message>
+    <message>
+        <source>Documents Mode</source>
+        <translation>Mode Documents</translation>
+    </message>
+    <message>
+        <source>Display date column on alphabetical sort</source>
+        <translation>Afficher la colonne des dates avec le tri alphabétique</translation>
+    </message>
+    <message>
+        <source>Empty trash for documents older than</source>
+        <translation>Supprimer de la corbeille les documents de plus de</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>jours</translation>
+    </message>
 </context>
 <context>
     <name>trapFlashDialog</name>
